new_serverversion: new_serverversion

Description Usage Details Examples

Description

Check if RStudio Server can be upgraded

Usage

1
2
3

Details

Fetches the version number from https://www.rstudio.com/products/rstudio/download-server/ and https://www.rstudio.com/products/rstudio/download/preview/. Compares it to the local version number and throws a message if the an upgrade can be performed.

Examples

1
2
# check if your RStudio Server Preview versions can be upgraded
new_serverversion_preview()

marcosci/upgrstuserv documentation built on May 7, 2019, 8:01 a.m.