upgrade_server: upgrade_server

Description Usage Details

Description

Upgrades your RStudio Server

Usage

1

Details

Checks again if an upgrade is needed. If so, it downloads the newest .deb file and installs it over the the older version. You must reload the window in your browser and RStudio Server should inform you about the upgrade after that.

If you perform an upgrade of RStudio Server and an existing version of the server is currently running, then the upgrade process will also ensure that active sessions are immediately migrated to the new version. This includes the following behavior:

Running R sessions are suspended so that future interactions with the server automatically launch the updated R session binary

Currently connected browser clients are notified that a new version is available and automatically refresh themselves.

The core server binary is restarted


marcosci/upgrstuserv documentation built on May 7, 2019, 8:01 a.m.