upgrstuserv-package: Convience functions to upgrade your RStudio Server

Description Details Author(s)

Description

upgrstuserv

Details

upgrstuserv is an R package to simplify the upgrade process of RStudio Server.

This package lets you check if there is a new version of RStudio Server. If required, one can perform an upgrade. If you perform an upgrade of RStudio Server and an existing version of the server is currently running, then the upgrade process will also ensure that active sessions are immediately migrated to the new version. This includes the following behavior:

Running R sessions are suspended so that future interactions with the server automatically launch the updated R session binary

Currently connected browser clients are notified that a new version is available and automatically refresh themselves.

The core server binary is restarted

Author(s)

Marco Sciaini msciain@gmail.com


marcosci/upgrstuserv documentation built on May 7, 2019, 8:01 a.m.