Description Usage Details Examples
Check if RStudio Server can be upgraded
1 2 3 |
Fetches the version number from https://www.rstudio.com/products/rstudio/download-server/ and https://www.rstudio.com/products/rstudio/download/preview/. Compares it to the local version number and throws a message if the an upgrade can be performed.
1 2 | # check if your RStudio Server Preview versions can be upgraded
new_serverversion_preview()
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.