upgrstuserv
upgrstuserv is an R package to simplify the upgrade process of RStudio Server.
This package lets you check if there is a new version of RStudio Server. If required, one can perform an upgrade. If you perform an upgrade of RStudio Server and an existing version of the server is currently running, then the upgrade process will also ensure that active sessions are immediately migrated to the new version. This includes the following behavior:
Running R sessions are suspended so that future interactions with the server automatically launch the updated R session binary
Currently connected browser clients are notified that a new version is available and automatically refresh themselves.
The core server binary is restarted
Marco Sciaini msciain@gmail.com
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.